@@ -5,10 +5,10 @@ from molp.models import Parameter
 
 
 class ParameterAdmin(admin.ModelAdmin):
-    list_display = ('name', 'value', 'version', 'channel', 'effect_time')
+    list_display = ('name', 'value', 'description', 'version', 'channel', 'effect_time')
     list_filter = ('app', 'channel', 'version')
 
-    search_fields = ('name', 'value')
+    search_fields = ('name', 'value', 'description')
 
 
 admin.site.register(Parameter, ParameterAdmin)
